@@ -309,7 +309,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             self.stats.inc_value("playwright/page_count/closed")
 
         server_ip_address = None
-        with suppress(AttributeError, KeyError, ValueError):
+        with suppress(AttributeError, KeyError, TypeError, ValueError):
             server_addr = await response.server_addr()
             server_ip_address = ip_address(server_addr["ipAddress"])
 
